@@ -1,22 +1,24 @@
-# $Id: test_stringio.py,v 1.2 2002/03/08 11:07:57 kjetilja Exp $
+#! /usr/bin/env python
+# vi:ts=4:et
+# $Id: test_stringio.py,v 1.4 2002/08/29 14:39:21 mfx Exp $
 
 import sys
-import pycurl
 try:
     from cStringIO import StringIO
 except ImportError:
     from StringIO import StringIO
+import pycurl
 
 url = 'http://curl.haxx.se/dev/'
 
 print 'Testing', pycurl.version
 
 body = StringIO()
-c = pycurl.init()
-c.setopt(pycurl.URL, url)
-c.setopt(pycurl.WRITEFUNCTION, body.write)
+c = pycurl.Curl()
+c.setopt(c.URL, url)
+c.setopt(c.WRITEFUNCTION, body.write)
 c.perform()
-c.cleanup()
+c.close()
 
 contents = body.getvalue()
 print contents
